==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-taskbar/taskbar_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="430"/>
        <source>Application</source>
        <translation>Aplikazioa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="463"/>
        <source>To &amp;Desktop</source>
        <translation>&amp;Mahaigainera</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="465"/>
        <source>&amp;All Desktops</source>
        <translation>Mahaigain &amp;guztiak</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="473"/>
        <source>Desktop &amp;%1</source>
        <translation>&amp;%1 mahaigaina</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="480"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Uneko mahaigainera</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="489"/>
        <source>Ma&amp;ximize</source>
        <translation>Maximizatu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="496"/>
        <source>Maximize vertically</source>
        <translation>Maximizatu bertikalki</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="501"/>
        <source>Maximize horizontally</source>
        <translation>Maximizatu horizontalki</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="507"/>
        <source>&amp;Restore</source>
        <translation>&amp;Leheneratu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="511"/>
        <source>Mi&amp;nimize</source>
        <translation>Minimizatu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="517"/>
        <source>Roll down</source>
        <translation>Zabaldu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="523"/>
        <source>Roll up</source>
        <translation>Bildu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="531"/>
        <source>&amp;Layer</source>
        <translation>&amp;Geruza</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="533"/>
        <source>Always on &amp;top</source>
        <translation>Beti &amp;goian</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="539"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normala</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="545"/>
        <source>Always on &amp;bottom</source>
        <translation>Beti &amp;behean</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="553"/>
        <source>&amp;Close</source>
        <translation>&amp;Itxi</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="81"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="82"/>
        <source>Close group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">LXQt ataza-kudeatzailearen ezarpenak</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">Leiho-zerrendaren edukia</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="26"/>
        <source>Show windows from c&amp;urrent desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all des&amp;ktops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="56"/>
        <source>Window &amp;grouping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="65"/>
        <source>Show popup on mouse hover </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="75"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="94"/>
        <source>Maximum button width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="107"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">Erakutsi uneko mahaigaineko leihoak</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">Erakutsi mahaigain guztietako leihoak</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="120"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">Leiho-zerrendaren itxura</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="84"/>
        <source>Button style</source>
        <translation>Botoi-estiloa</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">Botoien zabalera maximoa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="46"/>
        <source>Close on middle-click</source>
        <translation>Itxi erdiko botoia klikatzean</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Icon and text</source>
        <translation>Ikonoa eta testua</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only icon</source>
        <translation>Ikonoa soilik</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Only text</source>
        <translation>Testua soilik</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-taskbar/taskbar_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu">
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="477"/>
        <source>Application</source>
        <translation>Aplikazioa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="511"/>
        <source>To &amp;Desktop</source>
        <translation>&amp;Mahaigainera</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="513"/>
        <source>&amp;All Desktops</source>
        <translation>Mahaigain &amp;guztiak</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="521"/>
        <source>Desktop &amp;%1</source>
        <translation>&amp;%1 mahaigaina</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="528"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;Uneko mahaigainera</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="537"/>
        <source>Ma&amp;ximize</source>
        <translation>Maximizatu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="544"/>
        <source>Maximize vertically</source>
        <translation>Maximizatu bertikalki</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="549"/>
        <source>Maximize horizontally</source>
        <translation>Maximizatu horizontalki</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="555"/>
        <source>&amp;Restore</source>
        <translation>&amp;Leheneratu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="559"/>
        <source>Mi&amp;nimize</source>
        <translation>Minimizatu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>Roll down</source>
        <translation>Zabaldu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="571"/>
        <source>Roll up</source>
        <translation>Bildu</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="579"/>
        <source>&amp;Layer</source>
        <translation>&amp;Geruza</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="581"/>
        <source>Always on &amp;top</source>
        <translation>Beti &amp;goian</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="587"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normala</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="593"/>
        <source>Always on &amp;bottom</source>
        <translation>Beti &amp;behean</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Close</source>
        <translation>&amp;Itxi</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <source>LXQt Task Manager Settings</source>
        <translation type="vanished">LXQt ataza-kudeatzailearen ezarpenak</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation type="vanished">Leiho-zerrendaren edukia</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="34"/>
        <source>Show only windows from desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="46"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="53"/>
        <source>Show only minimized windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="60"/>
        <source>Raise minimized windows on current desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="77"/>
        <source>Window &amp;grouping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Show popup on mouse hover </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="96"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="115"/>
        <source>Maximum button width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="128"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="154"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="141"/>
        <source>Maximum button height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="174"/>
        <source>Use icons by WindowClass, if available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation type="vanished">Erakutsi uneko mahaigaineko leihoak</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation type="vanished">Erakutsi mahaigain guztietako leihoak</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="167"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation type="vanished">Leiho-zerrendaren itxura</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="105"/>
        <source>Button style</source>
        <translation>Botoi-estiloa</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation type="vanished">Botoien zabalera maximoa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="67"/>
        <source>Close on middle-click</source>
        <translation>Itxi erdiko botoia klikatzean</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>Ikonoa eta testua</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>Ikonoa soilik</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>Testua soilik</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
